==> RSTouchscreenNG-0.92.2.zip: RSTouchscreenNG/projects/binding/src/lib/actions/ConnectionAction.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Injectable} from '@angular/core';
import {NgRedux} from '@angular-redux/store';
import {RepetierState} from '..';

@Injectable()
export class ConnectionAction {

    static CONNECTED = 'CON_CONNECTED';
    static DISCONNECTED = 'CON_DISCONNECTED';
    static SET_SESSION = 'CON_SET_SESSION';
    static SET_APIKEY = 'CON_SET_APIKEY';
    static SET_CON_APIKEY = 'CON_SET_CON_APIKEY';
    static SET_CON_USER = 'CON_SET_CON_USER';

    constructor(private ngRedux: NgRedux<RepetierState>) {
    }

    connected(): void {
        this.ngRedux.dispatch({type: ConnectionAction.CONNECTED});
    }

    disconnected(): void {
        this.ngRedux.dispatch({type: ConnectionAction.DISCONNECTED});
    }

    setSession(session: string): void {
        this.ngRedux.dispatch({type: ConnectionAction.SET_SESSION, payload: session});
    }

    setApikey(key: string): void {
        this.ngRedux.dispatch({type: ConnectionAction.SET_APIKEY, payload: key});
    }

    setConnectionAPI(apikey: string, frontend: boolean): void {
        this.ngRedux.dispatch({
            type: ConnectionAction.SET_CON_APIKEY,
            payload: {apikey: apikey, frontend: frontend, authenticated: true, user: '', pasword: ''}
        });
    }

    setConnectionUser(user: string, password: string): void {
        this.ngRedux.dispatch({
            type: ConnectionAction.SET_CON_USER,
            payload: {apikey: '', frontend: false, authenticated: true, user: user, pasword: password}
        });
    }
}

==> RSTouchscreenNG-0.94.3.zip: RSTouchscreenNG/projects/binding/src/lib/actions/ConnectionAction.ts <==
/* (C) 2016-2020 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Injectable} from '@angular/core';
import {NgRedux} from '@angular-redux/store';
import {RepetierState} from '..';

@Injectable()
export class ConnectionAction {

    static CONNECTED = 'CON_CONNECTED';
    static DISCONNECTED = 'CON_DISCONNECTED';
    static SET_SESSION = 'CON_SET_SESSION';
    static SET_APIKEY = 'CON_SET_APIKEY';
    static SET_CON_APIKEY = 'CON_SET_CON_APIKEY';
    static SET_CON_USER = 'CON_SET_CON_USER';

    constructor(private ngRedux: NgRedux<RepetierState>) {
    }

    connected(): void {
        this.ngRedux.dispatch({type: ConnectionAction.CONNECTED});
    }

    disconnected(): void {
        this.ngRedux.dispatch({type: ConnectionAction.DISCONNECTED});
    }

    setSession(session: string): void {
        this.ngRedux.dispatch({type: ConnectionAction.SET_SESSION, payload: session});
    }

    setApikey(key: string): void {
        this.ngRedux.dispatch({type: ConnectionAction.SET_APIKEY, payload: key});
    }

    setConnectionAPI(apikey: string, frontend: boolean): void {
        this.ngRedux.dispatch({
            type: ConnectionAction.SET_CON_APIKEY,
            payload: {apikey: apikey, frontend: frontend, authenticated: true, user: '', password: ''}
        });
    }

    setConnectionUser(user: string, password: string): void {
        this.ngRedux.dispatch({
            type: ConnectionAction.SET_CON_USER,
            payload: {apikey: '', frontend: false, authenticated: true, user: user, password: password}
        });
    }
}
